@@ -1,12 +1,12 @@
 # coding=utf-8
 
 from django.db import models
-from djorm_expressions.models import ExpressionManager
 
+from django_earthdistance.models import EarthDistanceQuerySet
 
 class TestModel(models.Model):
     lat = models.FloatField()
     lon = models.FloatField()
 
-    objects = ExpressionManager()
+    objects = EarthDistanceQuerySet.as_manager()
 
